#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['smartmeter']

package_data = \
{'': ['*']}

install_requires = \
['requests >=2.24.0,<3.0.0', 'lxml >=4.6.3,<5.0.0']

extras_require = \
{'test': ['pytest ==5.4.3',
          'pytest-cov ==2.10.0',
          'pytest-asyncio >=0.14.0,<0.15.0',
          'mypy ==0.812',
          'flake8 >=3.8.3,<4.0.0',
          'black ==20.8b1',
          'lxml-stubs']}

setup(name='vienna-smartmeter',
      version='0.1.0',
      description='Unofficial Python wrapper for the Wiener Netze Smart Meter private API',
      author='Platysma',
      author_email=None,
      url='https://github.com/Platysma/vienna-smartmeter',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      python_requires='>=3.5',
     )



import unittest
from datetime import datetime

from smartmeter import Smartmeter


class SmartmeterTestCase(unittest.TestCase):
    def setUp(self):
        super(SmartmeterTestCase, self).setUp()
        self.api = Smartmeter(username="demouser", password="Demouser123")

    def tearDown(self):
        super(SmartmeterTestCase, self).tearDown()
        self.api.session.close()

    def test_confirm_login(self):
        """Confirm login"""
        self.assertTrue(len(self.api.profil()) > 0)

    def test_zaehlpunkte(self):
        """Confirm existence of zaehlpunkte with demo user"""
        zp = self.api.zaehlpunkte()
        self.assertTrue(len(zp) > 0)
        self.assertTrue(len(zp[0]["zaehlpunkte"]) > 0)

    def test_ereignisse(self):
        """Confirm existence of ereignisse with demo user"""
        eg_query = self.api.ereignisse(datetime(2021, 1, 1), datetime(2021, 1, 2))
        self.assertEqual(len(eg_query), 1)
        self.assertEqual(eg_query[0]["name"], "Wäsche waschen")


if __name__ == "__main__":
    unittest.main()
